///////////////////////////////////////////////////////////////////////////////
//
// Filename: AncestorPersonNode.java
//
// Author:   Robert Thornburrow
// Project:  FamilyTree
// Created:  20th May 2001
//
// Purpose:  Representation of a person in an Ancestor Diagram.
//
// (c) Copyright R.H.Thornburrow, 2001
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
//
///////////////////////////////////////////////////////////////////////////////

package com.tsac.familytree.ancestor;

import com.tsac.familytree.Person;

import java.awt.Toolkit;
import java.awt.Font;
import java.awt.FontMetrics;
import java.awt.Graphics;
import java.awt.Rectangle;
import java.awt.Point;


public class AncestorPersonNode
    extends AncestorDiagramNode
{
    private static Font _nameFont = new Font( "Helvetica", Font.PLAIN, 12 );
    private static Font _dateFont = new Font( "Helvetica", Font.PLAIN, 10 );
    
    private String _name;
    private String _born;
    private String _died;
    private Rectangle _nameBounds = new Rectangle();
    private Rectangle _dateBounds = new Rectangle();


    public AncestorPersonNode( Person node )
    {
        _name = node.getName();
        
        if( _name == null ) _name = "";
        
        _born = "b." + ( (node.getBornYear() != 0) ? Integer.toString(node.getBornYear()) : "" );
        _died = "d." + ( (node.getDiedYear() != 0) ? Integer.toString(node.getDiedYear()) : "" );
        
        FontMetrics metrics = Toolkit.getDefaultToolkit().getFontMetrics( _nameFont );
        _nameBounds.width = metrics.stringWidth( _name );
        _nameBounds.height = metrics.getAscent() + metrics.getDescent();
        _nameBounds.y = metrics.getAscent();
        
        metrics = Toolkit.getDefaultToolkit().getFontMetrics( _dateFont );
        _dateBounds.width = Math.max( metrics.stringWidth( _born ), metrics.stringWidth( _died ) );
        _dateBounds.height = metrics.getAscent() + metrics.getDescent();
        
        _bounds.width = Math.max( _nameBounds.width, _dateBounds.width );
        _bounds.height = _nameBounds.height*3;
        
        _nameBounds.x = (_bounds.width - _nameBounds.width)/2;
        _dateBounds.x = (_bounds.width - _dateBounds.width)/2;
        _dateBounds.y = _nameBounds.y + _nameBounds.height;
    }

    public void paint(Graphics g, Point origin, double fac, Font nameFont, Font dateFont)
    {
        g.setFont( nameFont );
        g.drawString( _name, origin.x + (int)((_bounds.x + _nameBounds.x)*fac), origin.y + (int)((_bounds.y + _nameBounds.y )*fac) );
        g.setFont( dateFont );
        g.drawString( _born, origin.x + (int)((_bounds.x + _dateBounds.x)*fac), origin.y + (int)((_bounds.y + _dateBounds.y)*fac) );
        g.drawString( _died, origin.x + (int)((_bounds.x + _dateBounds.x)*fac), origin.y + (int)((_bounds.y + _dateBounds.y + _dateBounds.height)*fac) );
    }
}