///////////////////////////////////////////////////////////////////////////////
//
// Filename: PageSetupDialog.java
//
// Author:   Robert Thornburrow
// Project:  FamilyTree
// Created:  20th May 2001
//
// Purpose:  Dialog for setting page margins.
//
// (c) Copyright R.H.Thornburrow, 2001
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
//
///////////////////////////////////////////////////////////////////////////////

package com.tsac.familytree.gui;

import java.awt.*;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import javax.swing.*;
import javax.swing.border.*;
import javax.swing.event.*;
import java.util.ResourceBundle;


public class PageSetupDialog
    extends javax.swing.JDialog
{
    static ResourceBundle res = ResourceBundle.getBundle("FamilyTree");
    
    public static final int PORTRAIT = 1;
    public static final int LANDSCAPE = 2;

    // Default page margins to use throughout
    public static int topMargin = 25;
    public static int bottomMargin = 75;
    public static int leftMargin = 25;
    public static int rightMargin = 25;
    public static int pageLayout = PORTRAIT;

    // Multipage settings
    public static boolean multipage = false;
    public static int multipageWidth  = 2;
    public static int multipageHeight = 1;

    public boolean _multipageEnabled = false;


	private PageSetupDialog(Frame parent)
	{
		super(parent);

		// This code is automatically generated by Visual Cafe when you add
		// components to the visual environment. It instantiates and initializes
		// the components. To modify the code, only use code syntax that matches
		// what Visual Cafe can generate, or Visual Cafe may be unable to back
		// parse your Java file into its visual environment.
		//{{INIT_CONTROLS
		getContentPane().setLayout(null);
		setSize(336,296);
		setVisible(false);
		marginsPnl.setLayout(new GridBagLayout());
		getContentPane().add(marginsPnl);
		marginsPnl.setBounds(12,12,312,96);
		marginsPnl.add(topLbl,new FamilyTreeGridBagConstraints(0,0,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(8,8,4,4),0,0));
		topLbl.setBounds(8,27,25,15);
		topMarginTxt.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		marginsPnl.add(topMarginTxt,new FamilyTreeGridBagConstraints(1,0,1,1,1.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(8,4,4,2),0,0));
		topMarginTxt.setBounds(41,25,59,19);
		marginsPnl.add(topPixLbl, new FamilyTreeGridBagConstraints(2,0,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.NONE,new Insets(8,2,4,8),0,0));
		topPixLbl.setBounds(104,27,34,15);
		marginsPnl.add(bottomLbl, new FamilyTreeGridBagConstraints(3,0,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(8,8,4,4),0,0));
		bottomLbl.setBounds(154,27,44,15);
		marginsPnl.add(rightLbl,new FamilyTreeGridBagConstraints(3,1,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,8,8,4),0,0));
		rightLbl.setBounds(154,54,44,15);
		bottomMarginTxt.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		marginsPnl.add(bottomMarginTxt,new FamilyTreeGridBagConstraints(4,0,1,1,1.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(8,4,4,2),0,0));
		bottomMarginTxt.setBounds(206,25,59,19);
		marginsPnl.add(bottomPixLbl, new FamilyTreeGridBagConstraints(5,0,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.NONE,new Insets(8,2,4,8),0,0));
		bottomPixLbl.setBounds(269,27,34,15);
		marginsPnl.add(leftLbl,new FamilyTreeGridBagConstraints(0,1,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,8,8,4),0,0));
		leftLbl.setBounds(8,54,25,15);
		leftMarginTxt.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		marginsPnl.add(leftMarginTxt,new FamilyTreeGridBagConstraints(1,1,1,1,1.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,4,8,2),0,0));
		leftMarginTxt.setBounds(41,52,59,19);
		marginsPnl.add(leftPixLbl, new FamilyTreeGridBagConstraints(2,1,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.NONE,new Insets(4,2,8,8),0,0));
		leftPixLbl.setBounds(104,54,34,15);
		rightMarginTxt.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		marginsPnl.add(rightMarginTxt,new FamilyTreeGridBagConstraints(4,1,1,1,1.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,4,8,2),0,0));
		rightMarginTxt.setBounds(206,52,59,19);
		marginsPnl.add(rightPixLbl, new FamilyTreeGridBagConstraints(5,1,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.NONE,new Insets(4,2,8,8),0,0));
		rightPixLbl.setBounds(269,54,34,15);
		layoutPnl.setLayout(new GridBagLayout());
		getContentPane().add(layoutPnl);
		layoutPnl.setBounds(12,108,312,48);
		portraitRad.setActionCommand("Portrait");
		layoutPnl.add(portraitRad,new FamilyTreeGridBagConstraints(0,0,1,1,1.0,1.0,java.awt.GridBagConstraints.SOUTH,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,8,4,8),0,0));
		portraitRad.setBounds(8,21,130,23);
		landscapeRad.setActionCommand("Landscape");
		layoutPnl.add(landscapeRad,new FamilyTreeGridBagConstraints(1,0,1,1,1.0,1.0,java.awt.GridBagConstraints.SOUTH,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,8,4,8),0,0));
		landscapeRad.setBounds(154,21,150,23);
		multipagePnl.setLayout(new GridBagLayout());
		getContentPane().add(multipagePnl);
		multipagePnl.setBounds(12,156,312,96);
		multipagePnl.add(widthLbl, new FamilyTreeGridBagConstraints(0,1,1,1,0.0,0.0,java.awt.GridBagConstraints.EAST,java.awt.GridBagConstraints.NONE,new Insets(4,8,8,4),0,0));
		widthLbl.setBounds(8,71,36,15);
		widthTxt.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		multipagePnl.add(widthTxt, new FamilyTreeGridBagConstraints(1,1,1,1,1.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,4,8,2),0,0));
		widthTxt.setBounds(52,69,55,19);
		multipagePnl.add(widthPagesLbl, new FamilyTreeGridBagConstraints(2,1,1,1,0.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.NONE,new Insets(4,2,8,8),0,0));
		widthPagesLbl.setBounds(111,71,35,15);
		multipagePnl.add(heightLbl, new FamilyTreeGridBagConstraints(3,1,1,1,0.0,0.0,java.awt.GridBagConstraints.EAST,java.awt.GridBagConstraints.NONE,new Insets(4,8,8,4),0,0));
		heightLbl.setBounds(162,71,39,15);
		heightTxt.setHorizontalAlignment(javax.swing.SwingConstants.RIGHT);
		multipagePnl.add(heightTxt, new FamilyTreeGridBagConstraints(4,1,1,1,1.0,0.0,java.awt.GridBagConstraints.CENTER,java.awt.GridBagConstraints.HORIZONTAL,new Insets(4,4,8,2),0,0));
		heightTxt.setBounds(209,69,55,19);
		multipagePnl.add(heightPagesLbl, new FamilyTreeGridBagConstraints(5,1,1,1,0.0,0.0,java.awt.GridBagConstraints.WEST,java.awt.GridBagConstraints.NONE,new Insets(4,2,8,8),0,0));
		heightPagesLbl.setBounds(268,71,35,15);
		multipageCb.setActionCommand("Multi-page Printing");
		multipagePnl.add(multipageCb, new FamilyTreeGridBagConstraints(0,0,6,1,0.0,1.0,java.awt.GridBagConstraints.SOUTHWEST,java.awt.GridBagConstraints.NONE,new Insets(8,8,4,8),0,0));
		multipageCb.setBounds(8,38,131,23);
		okBtn.setActionCommand("OK");
		getContentPane().add(okBtn);
		okBtn.setBounds(144,264,84,24);
		cancelBtn.setActionCommand("Cancel");
		getContentPane().add(cancelBtn);
		cancelBtn.setBounds(240,264,84,24);
		//$$ titledBorder1.move(0,564);
		//$$ etchedBorder1.move(24,564);
		//}}
		
		setTitle(res.getString("Page_Setup"));
		topLbl.setText(res.getString("Top_"));
		topPixLbl.setText(res.getString("pixels"));
		bottomLbl.setText(res.getString("Bottom_"));
		bottomPixLbl.setText(res.getString("pixels"));
		rightLbl.setText(res.getString("Right_"));
		rightPixLbl.setText(res.getString("pixels"));
		leftLbl.setText(res.getString("Left_"));
		leftPixLbl.setText(res.getString("pixels"));
		portraitRad.setText(res.getString("Portrait"));
		landscapeRad.setText(res.getString("Landscape"));
		widthLbl.setText(res.getString("Width_"));
		widthPagesLbl.setText(res.getString("pages"));
		heightLbl.setText(res.getString("Height_"));
		heightPagesLbl.setText(res.getString("pages"));
		multipageCb.setText(res.getString("Multi_page_Printing"));
		okBtn.setText(res.getString("OK"));
		cancelBtn.setText(res.getString("Cancel"));

		marginsPnl.setBorder(marginsTitBdr);
		layoutPnl.setBorder(layoutTitBdr);
		multipagePnl.setBorder(multipageTitBdr);

        layoutGrp.add( portraitRad );
        layoutGrp.add( landscapeRad );

		modelToView();

		portraitRad.addActionListener( new ActionListener() {
		    public void actionPerformed( ActionEvent e ) {
		        actionPortraitClicked();
		    }
		} );

		landscapeRad.addActionListener( new ActionListener() {
		    public void actionPerformed( ActionEvent e ) {
		        actionLandscapeClicked();
		    }
		} );

		multipageCb.addChangeListener( new ChangeListener() {
		    public void stateChanged( ChangeEvent e ) {
		        actionMultipageClicked();
		    }
		} );

		okBtn.addActionListener( new ActionListener() {
		    public void actionPerformed( ActionEvent e ) {
		        actionOk();
		    }
		} );

		cancelBtn.addActionListener( new ActionListener() {
		    public void actionPerformed( ActionEvent e ) {
		        setVisible( false );
		    }
		} );
	}

	public PageSetupDialog( Frame parent, boolean multipageEnabled )
	{
		this( parent );

        _multipageEnabled = multipageEnabled;

		multipagePnl.setEnabled( multipageEnabled );
		multipageTitBdr.setTitleColor( multipageEnabled ? Color.black : Color.lightGray );
		multipageCb.setEnabled( multipageEnabled );

		if( !multipageEnabled )
		{
		    multipageCb.setSelected( false );
		    widthLbl.setEnabled( false );
		    widthTxt.setEnabled( false );
		    widthPagesLbl.setEnabled( false );
		    heightLbl.setEnabled( false );
		    heightTxt.setEnabled( false );
		    heightPagesLbl.setEnabled( false );
		}
	}

	public void setVisible(boolean b)
	{
		if (b)
			setLocation(50, 50);
		super.setVisible(b);
	}

	public void addNotify()
	{
		// Record the size of the window prior to calling parents addNotify.
		Dimension size = getSize();

		super.addNotify();

		if (frameSizeAdjusted)
			return;
		frameSizeAdjusted = true;

		// Adjust size of frame according to the insets
		Insets insets = getInsets();
		setSize(insets.left + insets.right + size.width, insets.top + insets.bottom + size.height);
	}

	// Used by addNotify
	boolean frameSizeAdjusted = false;

	//{{DECLARE_CONTROLS
	javax.swing.JPanel marginsPnl = new javax.swing.JPanel();
	javax.swing.JLabel topLbl = new javax.swing.JLabel();
	javax.swing.JTextField topMarginTxt = new javax.swing.JTextField();
	javax.swing.JLabel topPixLbl = new javax.swing.JLabel();
	javax.swing.JLabel bottomLbl = new javax.swing.JLabel();
	javax.swing.JLabel rightLbl = new javax.swing.JLabel();
	javax.swing.JTextField bottomMarginTxt = new javax.swing.JTextField();
	javax.swing.JLabel bottomPixLbl = new javax.swing.JLabel();
	javax.swing.JLabel leftLbl = new javax.swing.JLabel();
	javax.swing.JTextField leftMarginTxt = new javax.swing.JTextField();
	javax.swing.JLabel leftPixLbl = new javax.swing.JLabel();
	javax.swing.JTextField rightMarginTxt = new javax.swing.JTextField();
	javax.swing.JLabel rightPixLbl = new javax.swing.JLabel();
	javax.swing.JPanel layoutPnl = new javax.swing.JPanel();
	javax.swing.JRadioButton portraitRad = new javax.swing.JRadioButton();
	javax.swing.JRadioButton landscapeRad = new javax.swing.JRadioButton();
	javax.swing.JPanel multipagePnl = new javax.swing.JPanel();
	javax.swing.JLabel widthLbl = new javax.swing.JLabel();
	javax.swing.JTextField widthTxt = new javax.swing.JTextField();
	javax.swing.JLabel widthPagesLbl = new javax.swing.JLabel();
	javax.swing.JLabel heightLbl = new javax.swing.JLabel();
	javax.swing.JTextField heightTxt = new javax.swing.JTextField();
	javax.swing.JLabel heightPagesLbl = new javax.swing.JLabel();
	javax.swing.JCheckBox multipageCb = new javax.swing.JCheckBox();
	javax.swing.JButton okBtn = new javax.swing.JButton();
	javax.swing.JButton cancelBtn = new javax.swing.JButton();
	//}}

    EtchedBorder etchedBdr = new EtchedBorder();
    TitledBorder marginsTitBdr = new TitledBorder( etchedBdr, res.getString("Page_Margins") );
    TitledBorder layoutTitBdr  = new TitledBorder( etchedBdr, res.getString("Layout") );
    TitledBorder multipageTitBdr  = new TitledBorder( etchedBdr, res.getString("Multi_page_Layout") );
    ButtonGroup layoutGrp = new ButtonGroup();


    public void modelToView()
    {
        portraitRad.setSelected( pageLayout == PORTRAIT );
        landscapeRad.setSelected( pageLayout == LANDSCAPE );

        if( pageLayout == PORTRAIT )
        {
		    topMarginTxt.setText( new Integer(topMargin).toString() );
		    bottomMarginTxt.setText( new Integer(bottomMargin).toString() );
		    leftMarginTxt.setText( new Integer(leftMargin).toString() );
		    rightMarginTxt.setText( new Integer(rightMargin).toString() );
		}
		else
		{
		    topMarginTxt.setText( new Integer(rightMargin).toString() );
		    bottomMarginTxt.setText( new Integer(leftMargin).toString() );
		    leftMarginTxt.setText( new Integer(topMargin).toString() );
		    rightMarginTxt.setText( new Integer(bottomMargin).toString() );
		}

		multipageCb.setSelected( multipage );
		widthLbl.setEnabled( multipage );
		widthTxt.setEnabled( multipage );
		widthTxt.setText( new Integer(multipageWidth).toString() );
		widthPagesLbl.setEnabled( multipage );
		heightLbl.setEnabled( multipage );
		heightTxt.setEnabled( multipage );
		heightTxt.setText( new Integer(multipageHeight).toString() );
		heightPagesLbl.setEnabled( multipage );
    }


    public void actionPortraitClicked()
    {
        if( portraitRad.isSelected() && (pageLayout == LANDSCAPE) )
        {
            pageLayout = PORTRAIT;
            layoutChanged();
        }
    }

    public void actionLandscapeClicked()
    {
        if( landscapeRad.isSelected() && (pageLayout == PORTRAIT) )
        {
            pageLayout = LANDSCAPE;
            layoutChanged();
        }
    }

    public void layoutChanged()
    {
        String lef = leftMarginTxt.getText();
        String rig = rightMarginTxt.getText();
        String bot = bottomMarginTxt.getText();
        String top = topMarginTxt.getText();

        if( pageLayout == PORTRAIT )
        {
		    topMarginTxt.setText( lef );
		    bottomMarginTxt.setText( rig );
		    leftMarginTxt.setText( bot );
		    rightMarginTxt.setText( top );
		}
		else
		{
		    leftMarginTxt.setText( top );
		    rightMarginTxt.setText( bot );
		    bottomMarginTxt.setText( lef );
		    topMarginTxt.setText( rig );
		}
    }


    public void actionMultipageClicked()
    {
        multipage = multipageCb.isSelected();

		widthLbl.setEnabled( multipage );
		widthTxt.setEnabled( multipage );
		widthPagesLbl.setEnabled( multipage );
		heightLbl.setEnabled( multipage );
		heightTxt.setEnabled( multipage );
		heightPagesLbl.setEnabled( multipage );
    }


    public void actionOk()
    {
        try
        {
            // parse everything first
            int top = Integer.parseInt( topMarginTxt.getText() );
            int bot = Integer.parseInt( bottomMarginTxt.getText() );
            int lef = Integer.parseInt( leftMarginTxt.getText() );
            int rig = Integer.parseInt( rightMarginTxt.getText() );
            int mpw = Integer.parseInt( widthTxt.getText() );
            int mph = Integer.parseInt( heightTxt.getText() );

            // then set the globals
            if( pageLayout == PORTRAIT )
            {
                topMargin    = top;
                bottomMargin = bot;
                leftMargin   = lef;
                rightMargin  = rig;
            }
            else
            {
                topMargin    = lef;
                bottomMargin = rig;
                leftMargin   = bot;
                rightMargin  = top;
            }

            if( _multipageEnabled )
            {
                multipage = multipageCb.isSelected();
                multipageWidth  = mpw;
                multipageHeight = mph;
            }

            // and finally close the window
            setVisible( false );
        }
        catch( NumberFormatException e )
        {
            // the window remains open and the globals remain unchanged :-)
        }
    }
}